package com.ruoyi.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.PostUserMapper;
import com.ruoyi.system.domain.PostUser;
import com.ruoyi.system.service.IPostUserService;

/**
 * 权限模块 用户Service业务层处理
 *
 * @author ruoyi
 * @date 2023-01-16
 */
@Service
public class PostUserServiceImpl implements IPostUserService
{
    @Autowired
    private PostUserMapper postUserMapper;

    /**
     * 查询权限模块 用户
     *
     * @param id 权限模块 用户主键
     * @return 权限模块 用户
     */
    @Override
    public PostUser selectPostUserById(Long id)
    {
        return postUserMapper.selectPostUserById(id);
    }

    /**
     * 查询权限模块 用户列表
     *
     * @param postUser 权限模块 用户
     * @return 权限模块 用户
     */
    @Override
    public List<PostUser> selectPostUserList(PostUser postUser)
    {
        return postUserMapper.selectPostUserList(postUser);
    }

    /**
     * 新增权限模块 用户
     *
     * @param postUser 权限模块 用户
     * @return 结果
     */
    @Override
    public int insertPostUser(PostUser postUser)
    {
        return postUserMapper.insertPostUser(postUser);
    }

    /**
     * 修改权限模块 用户
     *
     * @param postUser 权限模块 用户
     * @return 结果
     */
    @Override
    public int updatePostUser(PostUser postUser)
    {
        return postUserMapper.updatePostUser(postUser);
    }

    /**
     * 批量删除权限模块 用户
     *
     * @param ids 需要删除的权限模块 用户主键
     * @return 结果
     */
    @Override
    public int deletePostUserByIds(Long[] ids)
    {
        return postUserMapper.deletePostUserByIds(ids);
    }

    /**
     * 删除权限模块 用户信息
     *
     * @param id 权限模块 用户主键
     * @return 结果
     */
    @Override
    public int deletePostUserById(Long id)
    {
        return postUserMapper.deletePostUserById(id);
    }
}
